@@ -58,7 +58,7 @@ typedef struct {
   int feature;		    /* Feature Overridden?   IN      */
   int train_pristine;       /* Train Pristine?       IN      */
   void *dbh;                /* Database Handle       IN      */
-  u_int32_t flags;          /* Flags DAF_            IN      */
+  unsigned long long flags; /* Flags DAF_            IN      */
   int training_buffer;	    /* Sedation Level 0-10   IN      */
   char *recipient;          /* Current Recipient             */
   char mailer_args[256];        /* Delivery Args     IN      */
