@@ -289,7 +289,7 @@ int client_connect(AGENT_CTX *ATX, int flags) {
     if (_ds_read_attribute(agent_config, "DeliveryPort"))
       port = atoi(_ds_read_attribute(agent_config, "DeliveryPort"));
 
-    if (host[0] == '/') 
+    if (host && host[0] == '/') 
       domain = 1;
 
   } else {
@@ -298,7 +298,7 @@ int client_connect(AGENT_CTX *ATX, int flags) {
     if (_ds_read_attribute(agent_config, "ClientPort"))
       port = atoi(_ds_read_attribute(agent_config, "ClientPort"));
 
-    if (host[0] == '/')
+    if (host && host[0] == '/')
       domain = 1;
   }
 
