@@ -2024,7 +2024,7 @@ CHI_NEXT:
     _ds_factor_destroy(factor_chi);
 
   /* If somehow we haven't yet assigned a probability, assign one */
-  if (CTX->probability) 
+  if (CTX->probability == DSP_UNCALCULATED)
   {
     if (CTX->algorithms & DSA_GRAHAM)
       CTX->probability = bay_result;
