@@ -1021,7 +1021,10 @@ _ds_create_signature_id (DSPAM_CTX * CTX, char *buf, size_t len)
   pid = getpid ();
   if (_ds_match_attribute(CTX->config->attributes, "MySQLUIDInSignature", "on"))
   {
-    p = _mysql_drv_getpwnam (CTX, CTX->username);
+    if (!CTX->group || CTX->flags & DSF_MERGED)
+      p = _mysql_drv_getpwnam (CTX, CTX->username);
+    else
+      p = _mysql_drv_getpwnam (CTX, CTX->group);
     if (!p) {
       LOG(LOG_ERR, "Unable to determine UID for %s", CTX->username);
       return EINVAL;
@@ -2344,7 +2347,7 @@ int _ds_pref_set(config_t config, const char *user, const char *home,
 int _ds_pref_del(config_t config, const char *user, const char *home,
   const char *attrib, void *dbh)
 {
-  return _ds_pref_del(config, user, home, attrib, dbh);
+  return _ds_ff_pref_del(config, user, home, attrib, dbh);
 }
 #endif
 
