@@ -2503,6 +2503,6 @@ int _ds_pref_set(config_t config, const char *user, const char *home,
 int _ds_pref_del(config_t config, const char *user, const char *home,
   const char *attrib, void *dbh)
 {
-  return _ds_pref_del(config, user, home, attrib, dbh);
+  return _ds_ff_pref_del(config, user, home, attrib, dbh);
 }
 
