@@ -940,6 +940,7 @@ int
 _ds_init_storage (DSPAM_CTX * CTX, void *dbh)
 {
   struct _pgsql_drv_storage *s;
+  int ver = 0;
 
   /* don't init if we're already initted */
   if (CTX->storage != NULL)
@@ -955,17 +956,23 @@ _ds_init_storage (DSPAM_CTX * CTX, void *dbh)
     return EUNKNOWN;
   }
 
+  if (dbh) {
+      s->dbh = dbh;
+      ver = _pgsql_drv_get_dbversion(s);
+      if (ver < 0) {
+          LOG(LOG_WARNING, "_ds_init_storage: connection failed.");
+          free(s);
+          return EFAILURE;
+      }
+  } else {
+    s->dbh = _pgsql_drv_connect(CTX);
+  }
+
   s->dbh_attached = (dbh) ? 1 : 0;
   s->u_getnextuser[0] = 0;
   memset(&s->p_getpwnam, 0, sizeof(struct passwd));
   memset(&s->p_getpwuid, 0, sizeof(struct passwd));
 
-  if (dbh) {
-    s->dbh = dbh;
-  } else {
-    s->dbh = _pgsql_drv_connect(CTX);
-  }
-
   if (s->dbh == NULL || PQstatus(s->dbh) == CONNECTION_BAD)
   {
     LOG (LOG_WARNING, "%s", PQerrorMessage(s->dbh) );
@@ -994,7 +1001,10 @@ _ds_init_storage (DSPAM_CTX * CTX, void *dbh)
   s->control_sh = 0;  
 
   /* init db version and token type */
-  s->pg_major_ver = _pgsql_drv_get_dbversion(s);
+  if (ver)
+    s->pg_major_ver = ver;
+  else
+    s->pg_major_ver = _pgsql_drv_get_dbversion(s);
   s->pg_token_type = _pgsql_drv_token_type(s,NULL,0);
 
   /* get spam totals on successful init */
@@ -1061,7 +1071,10 @@ _ds_create_signature_id (DSPAM_CTX * CTX, char *buf, size_t len)
   pid = getpid ();
   if (_ds_match_attribute(CTX->config->attributes, "PgSQLUIDInSignature", "on"))
   {
-    p = _pgsql_drv_getpwnam (CTX, CTX->username);
+    if (!CTX->group || CTX->flags & DSF_MERGED)
+      p = _pgsql_drv_getpwnam (CTX, CTX->username);
+    else
+      p = _pgsql_drv_getpwnam (CTX, CTX->group);
     if (!p) {
       LOG(LOG_ERR, "Unable to determine UID for %s", CTX->username);
       return EINVAL;
@@ -2433,7 +2446,7 @@ int _ds_pref_set(config_t config, const char *user, const char *home,
 int _ds_pref_del(config_t config, const char *user, const char *home,
   const char *attrib, void *dbh)
 {
-  return _ds_pref_del(config, user, home, attrib, dbh);
+  return _ds_ff_pref_del(config, user, home, attrib, dbh);
 }
 
 #endif
