@@ -304,12 +304,12 @@ int _ds_pref_del(
   const char *attrib,
   void *dbh)
 {
-  int (*ptr)(config_t, const char *, const char *, void *);
-  ptr = (int (*)(config_t, const char *, const char *, void *))dlsym(_drv_handle, "_ds_pref_del");
+  int (*ptr)(config_t, const char *, const char *, const char *, void *);
+  ptr = (int (*)(config_t, const char *, const char *, const char *, void *))dlsym(_drv_handle, "_ds_pref_del");
   if (!ptr) {
     LOG(LOG_CRIT, "dlsym(_ds_pref_del) failed: %s", dlerror());
     return EFAILURE;
   }
-  return (*ptr)(config, user, home, dbh);
+  return (*ptr)(config, user, home, attrib, dbh);
 }
 
