@@ -1,4 +1,4 @@
-REM $Id: ora_objects.sql,v 1.1 2004/10/24 20:51:55 jonz Exp $
+REM $Id: ora_objects.sql,v 1.2 2006/01/24 14:39:38 jonz Exp $
 
 CREATE TABLE DSPAM_TOKEN_DATA (
   USER_ID NUMBER(5),
@@ -38,17 +38,3 @@ CREATE TABLE DSPAM_STATS (
 )
 /
 
-CREATE TABLE DSPAM_NEURAL_DATA (
-  USER_ID NUMBER(5),
-  NODE NUMBER(5), 
-  TOTAL_CORRECT NUMBER,
-  TOTAL_INCORRECT NUMBER
-)
-/
-
-CREATE INDEX ID_NEURAL_DATA_01 ON
-  DSPAM_NEURAL_DATA(USER_ID);
-
-CREATE INDEX ID_NEURAL_DATA_02 ON
-  DSPAM_NEURAL_DATA(USER_ID,NODE);
-
